@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::StaticInstall; # git description: v0.003-9-gedae895
+package Dist::Zilla::Plugin::StaticInstall; # git description: v0.004-15-gde88b76
 # ABSTRACT: (EXPERIMENTAL, DANGEROUS) Identify a distribution as eligible for static installation
 # KEYWORDS: distribution metadata toolchain static dynamic installation
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -14,7 +14,7 @@ with 'Dist::Zilla::Role::MetaProvider',
 use Moose::Util::TypeConstraints;
 use MooseX::Types::Moose qw(Str Bool);
 use Scalar::Util 'blessed';
-use List::Util 'first';
+use List::Util 1.33 qw(first any);
 use namespace::autoclean;
 
 my $mode_type = enum([qw(off on auto)]);
@@ -54,8 +54,13 @@ sub metadata
 {
     my $self = shift;
     my $mode = $self->mode;
-    return +{ x_static_install => 0 } if $mode eq 'off';
-    return +{ x_static_install => 1 } if $mode eq 'on';
+
+    my $value = $mode eq 'on' ? 1 : $mode eq 'off' ? 0 : undef;
+    if (defined $value)
+    {
+        $self->log([ 'setting x_static_install to %s', $value ]);
+        return +{ x_static_install => $value };
+    }
 
     # if mode = auto and dry_run = 0, we'll add it later
     return +{};
@@ -68,24 +73,32 @@ sub setup_installer
     # even if mode = off or on, we still run all the heuristics, as an extra check.
     my ($value, $message) = $self->_heuristics;
 
-    if ($self->mode eq 'on' and not $value)
+    my $distmeta = $self->zilla->distmeta;
+
+    if ($self->mode ne 'off' and exists $distmeta->{x_static_install} and ($distmeta->{x_static_install} xor $value))
     {
-        $self->log_fatal(ref $message
-            ? [ 'mode = on but this distribution is ineligible: ' . $message->[0], splice(@$message, 1) ]
-            : 'mode = on but this distribution is ineligible: ' . $message
-        );
+        $self->log_fatal('something set x_static_install = 0 but we want to set it to 1') if $value;
+
+        my $str1 = $self->mode eq 'on' ? 'mode = on' : 'x_static_install was set';
+        $message = [ $message ] if not ref $message;
+
+        $self->log_fatal([
+            $str1 . ' but this distribution is ineligible: ' . $message->[0],
+            splice(@$message, 1)
+        ]);
     }
 
-    # be noisy if requested, or if we aren't enabling the flag but we could be
-    my $log = $self->dry_run || ($self->mode eq 'off' && $value) ? 'log' : 'log_debug';
+    $self->${ \ ($self->dry_run ? 'log' : 'log_debug') }($message) if $message;
 
-    $self->$log($message) if $message;
+    # say what we would do, if dry run or heuristic different than requested
+    $self->log([ 'would set x_static_install to %s', $value ])
+        if $self->dry_run or ($value and $self->mode eq 'off');
 
-    $self->$log([ '%s x_static_install to %s',
-            ($self->mode ne 'auto' or $self->dry_run) ? 'would set' : 'setting',
-            $value ]);
-
-    $self->zilla->distmeta->{x_static_install} = $value if $self->mode eq 'auto' and not $self->dry_run;
+    if (not exists $distmeta->{x_static_install} and $self->mode eq 'auto' and not $self->dry_run)
+    {
+        $self->log([ 'setting x_static_install to %s', $value ]);
+        $distmeta->{x_static_install} = $value;
+    }
 }
 
 # returns value, log message
@@ -113,8 +126,7 @@ sub _heuristics
             join(', ', sort @build_requires) ]) if @build_requires;
 
     $self->$log('checking sharedirs');
-    my $share_dir_map = $self->zilla->_share_dir_map;
-    my @module_sharedirs = keys %{ $share_dir_map->{module} };
+    my @module_sharedirs = keys %{ $self->zilla->_share_dir_map->{module} };
     return (0, [ 'found module sharedir%s for %s',
             @module_sharedirs > 1 ? 's' : '',
             join(', ', sort @module_sharedirs) ]) if @module_sharedirs;
@@ -129,7 +141,7 @@ sub _heuristics
 
     # only these installer plugins can be trusted to not add disqualifying content
     my @other_installers = grep { blessed($_) !~ /^Dist::Zilla::Plugin::((MakeMaker|ModuleBuildTiny)(::Fallback)?|StaticInstall)$/ } @installers;
-    return (0, [ 'found install tool%s %s that will add extra content to Makefile.PL,Build.PL',
+    return (0, [ 'found install tool%s %s that will add extra content to Makefile.PL, Build.PL',
             @other_installers > 1 ? 's' : '',
             join(', ', sort map { blessed($_) } @other_installers) ]) if @other_installers;
 
@@ -144,6 +156,8 @@ sub _heuristics
                 if $added_by =~ /from coderef added by/
                     or $added_by =~ /filename set by/
                     or ($added_by =~ /content set by .* \((.*) line \d+\)/
+                        and not ($1 eq 'Dist::Zilla::Plugin::MakeMaker::Awesome'
+                                 and any { blessed($_) eq 'Dist::Zilla::Plugin::MakeMaker::Fallback' } @installers)
                         and $1 !~ /Dist::Zilla::Plugin::(MakeMaker|ModuleBuildTiny)(::Fallback)?$/);
         }
     }
@@ -189,7 +203,7 @@ Dist::Zilla::Plugin::StaticInstall - (EXPERIMENTAL, DANGEROUS) Identify a distri
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -227,6 +241,8 @@ client.
 
 The current preconditions for C<x_static_install> being true include:
 
+=for stopwords sharedir
+
 =over 4
 
 =item *
@@ -243,6 +259,10 @@ no prerequisites in build-requires
 
 =item *
 
+no L<module sharedir|Dist::Zilla::Plugin::ModuleShareDirs> (a L<distribution sharedir|Dist::Zilla::Plugin::ShareDir> is okay)
+
+=item *
+
 no installer plugins permitted other than:
 
 =over 4
